#include <Servo.h>
#include <TinyGPS++.h>
#include <SoftwareSerial.h>

Servo headTiltServo;  // create servo object to control a servo
Servo headPanServo;  // create servo object to control a servo
// twelve servo objects can be created on most boards


//----
// TinyGPS++
static const int RXPin = 18, TXPin = 19;
static const uint32_t GPSBaud = 4800;
TinyGPSPlus gps;
SoftwareSerial ss(RXPin, TXPin);

//----

int pos = 0;    // variable to store the servo position

void setup() {
  
  Serial.begin(115200);
  ss.begin(GPSBaud);
    
  Serial.println(F("DeviceExample.ino"));
  Serial.println(F("A simple demonstration of TinyGPS++ with an attached GPS module"));
  Serial.print(F("Testing TinyGPS++ library v. "));
  Serial.println(TinyGPSPlus::libraryVersion());
  Serial.println(F("by Mikal Hart"));
  Serial.println();
    
  headPanServo.attach(2);  // attaches the servo on pin 9 to the servo object
  headTiltServo.attach(3);  // attaches the servo on pin 9 to the servo object
  
  headPanServo.write(90);              // tell servo to go to position in variable 'pos'
  headTiltServo.write(90);              // tell servo to go to position in variable 'pos'
  

  //Serial.begin( 250000 );

  Serial.println("iBot v1.0 by OrbitusRobotics");
  Serial.println("BEGIN STARTUP SEQUENCE");
}

void loop() {
  
  //Serial.print("-");

  while (ss.available() > 0)
    if (gps.encode(ss.read()))
      displayInfo();

  if (millis() > 5000 && gps.charsProcessed() < 10)
  {
    Serial.println(F("No GPS detected: check wiring."));
    while(true);
  }
  /*
  delay(2000);
  headPanServo.write(89);
  delay(2000);
  headPanServo.write(91);
  delay(2000);
  headPanServo.write(90);
  

  for (pos = 70; pos <= 100; pos += 1) { // goes from 0 degrees to 180 degrees
    // in steps of 1 degree
    headTiltServo.write(pos);              // tell servo to go to position in variable 'pos'
    delay(15);                       // waits 15ms for the servo to reach the position
  }
  for (pos = 100; pos >= 70; pos -= 1) { // goes from 180 degrees to 0 degrees
    headTiltServo.write(pos);              // tell servo to go to position in variable 'pos'
    delay(15);                       // waits 15ms for the servo to reach the position
  }*/
 }


 
void displayInfo()
{
  Serial.print(F("Location: ")); 
  if (gps.location.isValid())
  {
    Serial.print(gps.location.lat(), 6);
    Serial.print(F(","));
    Serial.print(gps.location.lng(), 6);
  }
  else
  {
    Serial.print(F("INVALID"));
  }

  Serial.print(F("  Date/Time: "));
  if (gps.date.isValid())
  {
    Serial.print(gps.date.month());
    Serial.print(F("/"));
    Serial.print(gps.date.day());
    Serial.print(F("/"));
    Serial.print(gps.date.year());
  }
  else
  {
    Serial.print(F("INVALID"));
  }

  Serial.print(F(" "));
  if (gps.time.isValid())
  {
    if (gps.time.hour() < 10) Serial.print(F("0"));
    Serial.print(gps.time.hour());
    Serial.print(F(":"));
    if (gps.time.minute() < 10) Serial.print(F("0"));
    Serial.print(gps.time.minute());
    Serial.print(F(":"));
    if (gps.time.second() < 10) Serial.print(F("0"));
    Serial.print(gps.time.second());
    Serial.print(F("."));
    if (gps.time.centisecond() < 10) Serial.print(F("0"));
    Serial.print(gps.time.centisecond());
  }
  else
  {
    Serial.print(F("INVALID"));
  }

  Serial.println();
}

